diff projects/audio_in_FFT/render.cpp @ 56:3c3a1357657d newapi

Further API update to name three primary functions setup(), render() and cleanup(). Changed include paths so now can #include <BeagleRT.h>. Removed stale pru_rtaudio.bin file as this is now done as pru_rtaudio_bin.h. Updated examples to new API and fixed minor compiler warnings along the way. Network example needs further attention to compile.
author andrewm
date Wed, 15 Jul 2015 12:10:51 +0100
parents a6d223473ea2
children ac8eb07afcf5
line wrap: on
line diff
--- a/projects/audio_in_FFT/render.cpp	Mon Jun 15 18:16:00 2015 +0100
+++ b/projects/audio_in_FFT/render.cpp	Wed Jul 15 12:10:51 2015 +0100
@@ -6,7 +6,7 @@
  */
 
 
-#include "../../include/BeagleRT.h"
+#include <BeagleRT.h>
 #include <rtdk.h>
 #include <NE10.h>					// neon library
 #include <cmath>
@@ -23,7 +23,7 @@
 ne10_fft_cpx_float32_t* frequencyDomain;
 ne10_fft_cfg_float32_t cfg;
 
 // initialise_render() is called once before the audio rendering starts.
 // Use it to perform any initialisation and allocation which is dependent
 // on the period size or sample rate.
 //
@@ -32,7 +32,7 @@
 //
 // Return true on success; returning false halts the program.
 
-bool initialise_render(BeagleRTContext *context, void *userData)
+bool setup(BeagleRTContext *context, void *userData)
 {
 	// Retrieve a parameter passed in from the initAudio() call
 	gFFTSize = *(int *)userData;
@@ -74,16 +74,16 @@
 			gWritePointer = 0;
 		}
 
-		for(int channel = 0; channel < context->audioChannels; channel++)
+		for(unsigned int channel = 0; channel < context->audioChannels; channel++)
 			context->audioOut[n * context->audioChannels + channel] = (float) timeDomainOut[gWritePointer].r * gFFTScaleFactor;
 		gWritePointer++;
 	}
 }
 
 // cleanup_render() is called once at the end, after the audio has stopped.
 // Release any resources that were allocated in initialise_render().
 
-void cleanup_render(BeagleRTContext *context, void *userData)
+void cleanup(BeagleRTContext *context, void *userData)
 {
 	NE10_FREE(timeDomainIn);
 	NE10_FREE(timeDomainOut);
@@ -23,7 +23,7 @@
 ne10_fft_cfg_float32_t cfg;
 
-// initialise_render() is called once before the audio rendering starts.
+// setup() is called once before the audio rendering starts.
 // Use it to perform any initialisation and allocation which is dependent
 // on the period size or sample rate.
@@ -74,16 +74,16 @@
 }
 
-// cleanup_render() is called once at the end, after the audio has stopped.
-// Release any resources that were allocated in initialise_render().
+// cleanup() is called once at the end, after the audio has stopped.
+// Release any resources that were allocated in setup().
 